# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need Test::More ≥ 0.96, so use a bundled one if we don't have it
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.96) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Test-Script
Version:	1.16
Release:	1.%{__distinit}%{__distvers}
Summary:	Cross-platform basic tests for scripts
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Test-Script/
Source0:	http://search.cpan.org/CPAN/authors/id/P/PL/PLICEASE/Test-Script-%{version}.tar.gz
Source1:	T-S-1.001014.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(blib)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Glob)
BuildRequires:	perl(Test::Harness)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec) >= 0.80
BuildRequires:	perl(File::Spec::Unix)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IPC::Run3) >= 0.034
BuildRequires:	perl(Probe::Perl) >= 0.01
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder) >= 0.32
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Config)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(Test::Builder::Tester) >= 1.02
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Tester)
BuildRequires:	perl(Test2::Bundle::Extended)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(Test::More)

%description
The intent of this module is to provide a series of basic tests for scripts
in the bin directory of your Perl distribution.

%prep
%setup -q -n Test-Script-%{version}

# We need Test::More ≥ 0.96, so use a bundled one if we don't have it
%if %{old_test_more}
tar xfz %{SOURCE1}
find inc/Test -type f >> MANIFEST
%endif

%build
# Use our local Test-Simple if necessary
[ -d inc/Test/ ] && export PERL5LIB=$(pwd)/inc

perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
# Use our local Test-Simple if necessary
[ -d inc/Test/ ] && export PERL5LIB=$(pwd)/inc

make test

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Script.3*

%changelog
* Sun Mar  5 2017 Paul Howarth <paul@city-fan.org> - 1.16-1
- Update to 1.16
  - Stricter usage of plans

* Tue Feb 14 2017 Paul Howarth <paul@city-fan.org> - 1.15-1
- Update to 1.15
  - Fix bug where list reference arguments to script_compiles and script_runs
    are modified (GH#9)

* Thu Oct 13 2016 Paul Howarth <paul@city-fan.org> - 1.14-1
- Update to 1.14
  - Fix a regex in a test that fails on recent versions of Test2 on Windows
    (possibly others) (GH#8)
  - One of the tests was unreasonably slow, so it does not get run for users,
    and will be used for development only
  - Remove warning condition that happens with at least some older versions
    of Perl when using quotemeta without parentheses (GH#7)

* Thu Oct  6 2016 Paul Howarth <paul@city-fan.org> - 1.12-3
- BR: perl-generators where available

* Tue May  3 2016 Paul Howarth <paul@city-fan.org> - 1.12-1
- Update to 1.12
  - Including some optional Test2-based tests that should only be run with a
    merged Test2/Test::Builder (currently a dev release as Test::Simple on
    CPAN)
  - One possible fix for https://github.com/plicease/Test-Script/issues/5
  - Check for IO errors on temporary .pm file
- Add patch to silence 'Warning: Use of "quotemeta" without parentheses is
  ambiguous' warnings on older perls

* Mon Jun 22 2015 Paul Howarth <paul@city-fan.org> - 1.10-4
- Perl 5.22 rebuild

* Wed May 13 2015 Paul Howarth <paul@city-fan.org> - 1.10-1
- Update to 1.10
  - Workaround for buggy IPC::Run3 0.048 on MSWin32
    (https://github.com/plicease/Test-Script/issues/1)

* Fri May  8 2015 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
  - If IPC::Run3::run3 throws an exception it will now fail the test (with a
    helpful diagnostic) rather than crashing the test script
  - A script that is killed with a signal is now considered a failure as well
  - Use alternate expected exit and signal values with options as the second
    argument to script_runs
  - Ability to pass input via stdin to the script with script_runs
  - Ability to capture stdout and stderr from script with script_runs
  - Functions to test stdout and stderr:
    - script_stdout_is
    - script_stdout_isnt
    - script_stdout_like
    - script_stdout_unlike
    - script_stderr_is
    - script_stderr_isnt
    - script_stderr_like
    - script_stderr_unlike
- Bundle Test-Simple 1.x for testing on old distributions that don't have a
  recent enough version

* Wed May  6 2015 Paul Howarth <paul@city-fan.org> - 1.08-1
- Update to 1.08
  - Now works with or without blib (CPAN RT#81222, CPAN RT#102743)
  - Compatibility with older versions of Test::Builder::Tester (CPAN RT#81335)
  - Requires Perl 5.6.0
  - Migrate to Dist::Zilla
- This release by PLICEASE → update source URL
- Classify buildreqs by usage
- Drop workaround for old Test::More versions

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1.07-17
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.07-9
- Perl 5.16 post-bootstrap rebuild

* Mon Jul  2 2012 Paul Howarth <paul@city-fan.org> - 1.07-8
- BR: perl(Carp), perl(Cwd), perl(Exporter), perl(File::Path),
  perl(File::Spec), perl(File::Spec::Functions), perl(File::Spec::Unix) and
  perl(Test::Builder)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jun 30 2011 Paul Howarth <paul@city-fan.org> - 1.07-6
- Rebuild for perl 5.14.1 in Rawhide
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation
- Add support for perl_bootstrap macro
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.07-3
- Rebuild for perl 5.12.1 in Rawhide

* Fri May 28 2010 Paul Howarth <paul@city-fan.org> - 1.07-2
- Fix dist tag for RHEL-6 Beta

* Tue Nov 24 2009 Paul Howarth <paul@city-fan.org> - 1.07-1
- Update to 1.07 (second attempt at fixing the "Using" bug)
- Update patch for t/03_compiles_bad.t (also patches t/05_runs_bad.t now)
- Use search.cpan.org source URL
- Dist tag for Rawhide no longer needs special-casing

* Thu Sep 17 2009 Paul Howarth <paul@city-fan.org> - 1.06-1
- Update to 1.06 (fix t/03_compiles_bad.t)
- Update patch for t/03_compiles_bad.t (upstream fix requires
  Test::More >= 0.77)
- Manually add perl(Test::More) runtime dependency

* Tue Sep 15 2009 Paul Howarth <paul@city-fan.org> - 1.05-1
- Update to 1.05
  - change script_compiles_ok to script_compiles
  - add script_runs
  - attempt to support 5.6 properly
  - add dependency on Probe::Perl
  - full fidelity failure testing
  - update author tests
- Enable AUTOMATED_TESTING
- Buildreq Test::CPAN::Meta, Perl::MinimumVersion, Pod::Simple, Test::Pod, and
  Test::MinimumVersion
- Define RPM macros in global scope
- Patch t/03_compiles_bad.t to fix test failure when necessary

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 1.03-2
- Import from Fedora

* Tue Mar 11 2008 Ralf Corsépius <rc040203@freenet.de> - 1.03-1
- Upstream update.

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.02-4
- Rebuild for perl 5.10 (again)

* Sat Jan 12 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.02-3
- Rebuild for new perl

* Tue Sep 18 2007 Ralf Corsépius <rc040203@freenet.de> - 1.02-2
- Reflect license tag changes.
- BR: perl(Test::More).
- Remove BR: perl.
- Add chmod -x Changes lib/Test/*pm

* Tue Aug 07 2007 Ralf Corsépius <rc040203@freenet.de> - 1.02-1
- Specfile autogenerated by cpanspec 1.73.
